This scenario predicts that **{mortality}** per 100k population will die from
COVID-19. This number corresponds to **{fatality}** of those that became ill.
The model also predicts that **{infected}** of the population will become
infected, but only **{symptomatic}** of those will develop visible symptoms.

**IMPORTANT:** Models are simplifications and are highly dependent on good
parameters and good data. There are many aspects of COVID epidemiology that are
not yet very well understood and scientists are still looking for more accurate
values for many important parameters. The choices made here are best guesses
based on the current scientific knowledge about the epidemic. Changing
parameters to absurd values will create absurd predictions, so use with care...

The course of the epidemic also depends crucially on how communities react. This is
encoded in a very simplified way in the "intervention options" tab of the simulator.
We do not try to anticipate communities respond to the epidemic, but rather it
must be entered as an explicit input to the model. That is why we say therefore,
this calculator computes scenarios rather than trying to predict the future.
